Collapses data from all time series in mts into a
single-time series mts object using the function provided in the
FUN argument. The single-time series result will be located at the mean
longitude and latitude unless longitude and latitude
are specified.
Any columns of mts$meta that are constant across all records will be
retained in the returned mts$meta.
The core metadata associated with this location (e.g.
countryCode, stateCode, timezone, ...) will be determined from
the most common (or average) value found in mts$meta. This will be
a reasonable assumption for the vast majority of intended use cases where
data from multiple devices in close proximity are averaged together.