powered by
mts$data
This function is primarily for internal use.
Two successive steps are used to guarantee that the datetime axis contains no repeated values:
datetime
remove any duplicate records
guarantee that rows are in datetime order
mts_distinct(mts)
An mts object where each record is associated with a unique time. (A list with meta and data dataframes.)
meta
data
mts object