Learn R Programming

MazamaTimeSeries (version 0.3.0)

mts_filterDate: Date filtering for mts time series objects

Description

Subsets an mts object by date. This function always filters to day-boundaries. For sub-day filtering, use mts_setTimeAxis().

Dates can be anything that is understood by MazamaCoreUtils::parseDatetime() including either of the following recommended formats:

  • "YYYYmmdd"

  • "YYYY-mm-dd"

Timezone determination precedence assumes that if you are passing in POSIXct values then you know what you are doing:

  1. get timezone from startdate if it is POSIXct

  2. use passed in timezone

  3. get timezone from mts

Usage

mts_filterDate(
  mts = NULL,
  startdate = NULL,
  enddate = NULL,
  timezone = NULL,
  unit = "sec",
  ceilingStart = FALSE,
  ceilingEnd = FALSE
)

Value

A subset of the incoming mts time series object. (A list with meta and data dataframes.)

Arguments

mts

mts object.

startdate

Desired start date (ISO 8601).

enddate

Desired end date (ISO 8601).

timezone

Olson timezone used to interpret dates.

unit

Units used to determine time at end-of-day.

ceilingStart

Logical instruction to apply ceiling_date to the startdate rather than floor_date.

ceilingEnd

Logical instruction to apply ceiling_date to the enddate rather than floor_date.

See Also

mts_setTimeAxis

Examples

Run this code
library(MazamaTimeSeries)

example_mts %>%
  mts_filterDate(
    startdate = 20190703,
    enddate = 20190706
  ) %>%
  mts_extractData() %>%
  dplyr::pull(datetime) %>%
  range()

Run the code above in your browser using DataLab