Individual time series in mts$data are grouped by unit and then
summarized using FUN.
The most typical use case is creating daily averages where each day begins at
midnight. This function interprets times using the mts$data$datetime
tzone attribute so be sure that is set properly.
Day boundaries are calculated using the specified timezone or, if
NULL, the most common (hopefully only!) time zone found in
mts$meta$timezone. Leaving timezone = NULL, the default,
results in "local time" date filtering which is the most common use case.