Trims the date range of an mts object to local time date
boundaries which are within the time range of the mts object.
This has the effect of removing partial-day data records at the start and
end of the timeseries and is useful when calculating full-day statistics.
By default, multi-day periods of all-missing data at the beginning and end
of the timeseries are removed before trimming to date boundaries. If
trimEmptyDays = FALSE all records are retained except for partial days
beyond the first and after the last date boundary.
Day boundaries are calculated using the specified timezone or, if
NULL, mts$meta$timezone. Leaving timezone = NULL, the
default, results in "local time" date filtering which is the most
common use case.