Subsets a MazamaSingleTimeseries object by date. This function
always filters to day-boundaries. For sub-day filtering, use
sts_filterDatetime().
Dates can be anything that is understood by MazamaCoreUtils::parseDatetime()
including either of the following recommended formats:
Timezone determination precedence assumes that if you are passing in
POSIXct values then you know what you are doing.
get timezone from startdate if it is POSIXct
use passed in timezone
get timezone from sts